
<div align="center">
    <img src="images/picasa_workflow.png" alt="Logo" width="500" height="500">
</div>



### This is a project repository for -
* - Subedi, Sishir, and  Yongjin P. Park. "Decomposing patient heterogeneity of single-cell cancer data by cross-attention neural networks." [medRxiv 2025.06.04.25328900](https://www.medrxiv.org/content/10.1101/2025.06.04.25328900v1)



## Tutorial

For the step-by-step tutorial, please refer to <a href="https://github.com/causalpathlab/picasa/tree/main/picasa_reproducibility/analysis/tutorial">
notebooks </a>:

- Tutorial 1. <a href="https://github.com/causalpathlab/picasa/tree/main/picasa_reproducibility/analysis/tutorial/1_training_picasa_model.ipynb">
 Training PICASA model using simulated datasets.</a>

- Tutorial 2. <a href="https://github.com/causalpathlab/picasa/tree/main/picasa_reproducibility/analysis/tutorial/2_plotting_all_three_latent_umaps.ipynb">
Plotting all three latent representations learned by the model.</a>

- Tutorial 3. <a href="https://github.com/causalpathlab/picasa/tree/main/picasa_reproducibility/analysis/tutorial/3_attention_matrix_analysis.ipynb">
Analysis of the cross attention matrix estimated by the model.</a>

- Tutorial 4. <a href="https://github.com/causalpathlab/picasa/tree/main/picasa_reproducibility/analysis/tutorial/4_cancer_common_representation_analysis.ipynb">
Cancer common representation analysis.</a>

- Tutorial 5. <a href="https://github.com/causalpathlab/picasa/tree/main/picasa_reproducibility/analysis/tutorial/5_cancer_unique_representation_analysis.ipynb">
Cancer unique representation analysis.</a>

- Tutorial 6. <a href="https://github.com/causalpathlab/picasa/tree/main/picasa_reproducibility/analysis/tutorial/6_cancer_patient_outcome_analysis.ipynb">
Cancer patient outcome analysis.</a>
